Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1483)

Unified Diff: src/gpu/gl/GrGLCaps.cpp

Issue 2212593002: Remove color-dodge/burn from NVIDIA blacklist on 355.00+ (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/gl/GrGLCaps.cpp
diff --git a/src/gpu/gl/GrGLCaps.cpp b/src/gpu/gl/GrGLCaps.cpp
index 5a1a5b459baa5cc604fd24f6283b26c4d6755a9b..ea02d21c90e46332c215e68da2388535938049f4 100644
--- a/src/gpu/gl/GrGLCaps.cpp
+++ b/src/gpu/gl/GrGLCaps.cpp
@@ -972,8 +972,9 @@ void GrGLCaps::initBlendEqationSupport(const GrGLContextInfo& ctxInfo) {
SkASSERT(this->advancedBlendEquationSupport());
- if (kNVIDIA_GrGLDriver == ctxInfo.driver()) {
- // Blacklist color-dodge and color-burn on NVIDIA until the fix is released.
+ if (kNVIDIA_GrGLDriver == ctxInfo.driver() &&
+ ctxInfo.driverVersion() < GR_GL_DRIVER_VER(355,00)) {
+ // Blacklist color-dodge and color-burn on pre-355.00 NVIDIA.
fAdvBlendEqBlacklist |= (1 << kColorDodge_GrBlendEquation) |
(1 << kColorBurn_GrBlendEquation);
}
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698